@@ -10,7 +10,7 @@ package Devel::Cover::Collection;
 use 5.16.0;
 use warnings;
 
-our $VERSION = '1.22'; # VERSION
+our $VERSION = '1.24'; # VERSION
 
 use Devel::Cover::DB;
 use Devel::Cover::DB::IO::JSON;
@@ -377,6 +377,12 @@ sub generate_html {
             or die $template->error;
     }
 
+    my $about_f = "$d/about.html";
+    say "\nWriting about page to $about_f ...";
+
+    $template->process("about", { subdir => "latest/" }, $about_f)
+        or die $template->error;
+
     # print Dumper $vars;
     $self->write_json($vars);
 
@@ -613,7 +619,7 @@ package Devel::Cover::Collection::Template::Provider;
 use strict;
 use warnings;
 
-our $VERSION = '1.22'; # VERSION
+our $VERSION = '1.24'; # VERSION
 
 use base "Template::Provider";
 
@@ -664,8 +670,8 @@ http://www.pjcj.net
 </head>
 <body>
     [% content %]
-    <p/>
     <hr/>
+    <p>
     Coverage information from <a href="https://metacpan.org/module/Devel::Cover">
       Devel::Cover
     </a> by <a href="http://pjcj.net">Paul Johnson</a>.
@@ -673,15 +679,15 @@ http://www.pjcj.net
     <br/>
 
     Please report problems with this site to the
-    <a href="https://github.com/pjcj/Devel--Cover/issues">issue tracker</a>.
+    <a href="https://github.com/pjcj/Devel--Cover/issues">issue tracker</a>.</p>
 
-    <br/>
-    <br/>
+    <p><a href="http://cpancover.com/latest/about.html">About</a> the project.</p>
 
-    This server generously donated by
+    <p>This server generously donated by
     <a href="http://www.bytemark.co.uk/r/cpancover">
       <img src="http://www.bytemark.co.uk/images/subpages/spreadtheword/bytemark_logo_179_x_14.png" alt="bytemark"/>
     </a>
+    </p>
 </body>
 </html>
 EOT
@@ -693,7 +699,7 @@ $Templates{summary} = <<'EOT';
 
 <h2> Distributions </h2>
 
-Search for distributions by first character:<p/>
+<p>Search for distributions by first character:</p>
 
 [% FOREACH start = modules.keys.sort %]
     <a href="dist/[%- start -%].html">[% start %]</a>
@@ -707,6 +713,32 @@ Search for distributions by first character:<p/>
 [% END %]
 EOT
 
+$Templates{about} = <<'EOT';
+[% WRAPPER html %]
+
+<h1> CPANCover </h1>
+
+<h2> About </h2>
+
+<p>CPANCover is a project to provide code coverage information for <a
+href="https://metacpan.org"> CPAN</a> modules.  When a new module, or an update to an
+existing module, is uploaded to CPAN it will automatically be downloaded by
+CPANCover.  CPANCover will run the module's tests and measure the code coverage
+provided by the tests.  This information is then made available as HTML pages
+and JSON data.</p>
+
+<p>The coverage data is generated by <a
+href="https://metacpan.org/release/Devel-Cover">Devel::Cover</a>.
+
+<p>The source code is available at the
+  <a href="https://github.com/pjcj/Devel--Cover">GitHub repository</a>.
+  Contributions are also accepted for several
+  <a href="http://pjcj.net/devel-cover/projects.html">open projects</a>.
+</p>
+
+[% END %]
+EOT
+
 $Templates{module_by_start} = <<'EOT';
 [% WRAPPER html %]
 
@@ -768,7 +800,7 @@ Devel::Cover::Collection - Code coverage for a collection of modules
 
 =head1 VERSION
 
-version 1.22
+version 1.24
 
 =head1 SYNOPSIS
 
